@@ -22,9 +22,11 @@ class Header(models.Model):
     city = models.CharField(_('City'), max_length=100)
     country = models.CharField(_('Country'), max_length=100)
     email = models.EmailField(_('Email'), blank=True, max_length=100)
+    url = models.URLField(_('URL'), blank=True, max_length=100)
     phone = models.CharField(_('Phone'), max_length=100)
     cif = models.CharField(_('CIF/NIF'), max_length=100)
     more = models.TextField(_('Extra information'), blank=True)
+    budget_more = models.TextField(_('Budget Extra information'), blank=True)
 
     def __unicode__(self):
         return self.name + ' ' + self.address
@@ -191,3 +193,46 @@ class Line(models.Model):
         verbose_name = _('Line')
         verbose_name_plural = _('Lines')
 
+
+class Budget(models.Model):
+    """
+    Budget model
+    """
+    header = models.ForeignKey(Header, related_name="budget_header")
+    customer = models.ForeignKey(Customer, related_name="budget_customer")
+    taxes = models.ForeignKey(Tax, related_name="budget_taxes")
+    retentions = models.ForeignKey(Retention, related_name="budget_retentions")
+    currency = models.ForeignKey(Currency, related_name="budget_currency")
+    date = models.DateTimeField(_('Creation date'))
+    description1 = models.TextField(_('Description header'), blank=True)
+    description2 = models.TextField(_('Description footer'), blank=True)
+    total = models.CharField(_('Total'), max_length=200, blank=True, help_text=_('Calculated field'))
+    price_per_line = models.BooleanField(_("Show price per line?"))
+
+    def __unicode__(self):
+        return str(self.date)
+
+    class Meta:
+        verbose_name = _('Budget')
+        verbose_name_plural = _('Budgets')
+
+
+class BudgetLine(models.Model):
+    """
+    Budget Line model
+    """
+    budget = models.ForeignKey(Budget, related_name="budget_line")
+    reference = models.CharField(_('Reference'), max_length=200)
+    concept = models.CharField(_('Concept'), max_length=200)
+    quantity = models.CharField(_('Quantity'), max_length=200)
+    unit = models.ForeignKey(QuantityUnit, related_name="budget_quantityunit", blank=True, default='')
+    unit_price = models.CharField(_('Unit Price'), max_length=200)
+    amount = models.CharField(_('Ammount'), max_length=200)
+
+    def __unicode__(self):
+        #return self.reference + " " + self.quantity + "x" + self.unit_price
+        return self.reference
+
+    class Meta:
+        verbose_name = _('Budget Line')
+        verbose_name_plural = _('Budget Lines')
\ No newline at end of file
